django-plain-permissions
===============

[![Build Status](https://github.com/hassaanalansary/django-plain-permissions/actions/workflows/tests.yml/badge.svg)](https://github.com/hassaanalansary/django-plain-permissions/actions)


Documentation
=============
https://django-plain-permissions.readthedocs.io/en/latest/

Run tests
==========
```shell
pip install -r requirements_dev.txt
pytest
```

Contribute
==========

If you have great ideas for django-plain-permissions, or if you like to improve something,
feel free to fork this repository and/or create a pull request.
I'm open for suggestions.
If you like to discuss something with me (about django-plain-permissions), please open an issue.


#### GitHub repository: https://github.com/hassaanalansary/django-plain-permissions
#### issue tracker: https://github.com/hassaanalansary/django-plain-permissions/issues
